=====
To do
=====

Next version
============

- Read only archive for persons.

- Maybe: Full text search.

Longer term
===========

The following features might be implemented eventually:

- person data

  * store picture per person

- company as entity (?)

- import

  * vCard

  * SQLite (Apple's Addressbook.app)

- export

  * custom XLS export

  * LDAP export (?)

- more search abilities

  * full text search

  * combined search

  * wildcard search
